Skip to main contentModule core
Source pub use client::Client;
- client
- constants
- osc_receiver
- Position
- A 2D position in normalized coordinates (typically in the range
[0.0, 1.0]). - Size
- A 2D size with
width and height components in normalized coordinates. - TuioTime
- A timestamp used throughout the TUIO protocol, storing time as a combination
of whole seconds and a microsecond sub-second component.
- Velocity
- A 2D velocity vector representing the rate of change of a
Position per frame.
- TuioError
- Represents errors that can occur during TUIO processing and decoding.
- Profile
- Trait representing a TUIO profile — a typed, addressable OSC entity
(e.g. a cursor, object, blob, pointer, token, symbol, or bounds).